import { Keybinding, ResolvedKeybinding } from '@vscode/monaco-editor/esm/vs/base/common/keyCodes';
import { IKeyboardEvent } from '@vscode/monaco-editor/esm/vs/platform/keybinding/common/keybinding';
import { ApolloClient } from 'apollo-client';
import { InMemoryCache } from 'apollo-cache-inmemory';
import { IKeymapService, ILifecycleService, IClientConfigurationService, IEnvironmentService, INotificationService, ICommandService, IKeybindingService, IContextKeyService } from '@workbench-stack/core';
import { KeybindingResolver } from './keybinding-resolver';
import { ITextFileService } from '@files-stack/core';
import { AbstractKeybindingService } from './abstract-keybinding-service';
export declare class WorkbenchKeybindingService extends AbstractKeybindingService implements IKeybindingService {
    client: ApolloClient<any>;
    cache: InMemoryCache;
    private contextKeyService;
    commandService: ICommandService;
    notificationService: INotificationService;
    private lifecycleService;
    environmentService: IEnvironmentService;
    configurationService: IClientConfigurationService;
    private textFileService;
    private readonly keymapService;
    private _keyboardMapper;
    private _cachedResolver;
    private userKeybindings;
    constructor(client: ApolloClient<any>, cache: InMemoryCache, contextKeyService: IContextKeyService, commandService: ICommandService, notificationService: INotificationService, lifecycleService: ILifecycleService, environmentService: IEnvironmentService, configurationService: IClientConfigurationService, textFileService: ITextFileService, keymapService: IKeymapService);
    private postSetup;
    registerSchemaContribution(contribution: any): void;
    _dumpDebugInfo(): string;
    _dumpDebugInfoJSON(): string;
    customKeybindingsCount(): number;
    private updateResolver;
    protected _getResolver(): KeybindingResolver;
    protected _documentHasFocus(): boolean;
    private _resolveKeybindingItems;
    private _resolveUserKeybindingItems;
    private _assertBrowserConflicts;
    resolveKeybinding(kb: Keybinding): ResolvedKeybinding[];
    resolveKeyboardEvent(keyboardEvent: IKeyboardEvent): ResolvedKeybinding;
    resolveUserBinding(userBinding: string): ResolvedKeybinding[];
    getDefaultKeybindingsContent(): string;
    private static _getDefaultKeybindings;
    private static _getAllCommandsAsComment;
    mightProducePrintableCharacter(event: IKeyboardEvent): boolean;
}
