import { Keybinding, ResolvedKeybinding, SimpleKeybinding } from '@vscode/monaco-editor/esm/vs/base/common/keyCodes';
import { OperatingSystem } from '@vscode/monaco-editor/esm/vs/base/common/platform';
import { ScanCodeBinding } from '@vscode/monaco-editor/esm/vs/base/common/scanCode';
import { IKeyboardEvent } from '@vscode/monaco-editor/esm/vs/platform/keybinding/common/keybinding';
import { BaseResolvedKeybinding } from '@vscode/monaco-editor/esm/vs/platform/keybinding/common/baseResolvedKeybinding';
import { IKeyboardMapper } from '@workbench-stack/core';
export interface IMacLinuxKeyMapping {
    value: string;
    withShift: string;
    withAltGr: string;
    withShiftAltGr: string;
}
export interface IMacLinuxKeyboardMapping {
    [scanCode: string]: IMacLinuxKeyMapping;
}
export declare function macLinuxKeyboardMappingEquals(a: IMacLinuxKeyboardMapping | null, b: IMacLinuxKeyboardMapping | null): boolean;
export declare class NativeResolvedKeybinding extends BaseResolvedKeybinding<ScanCodeBinding> {
    private readonly _mapper;
    constructor(mapper: MacLinuxKeyboardMapper, os: OperatingSystem, parts: ScanCodeBinding[]);
    protected _getLabel(keybinding: ScanCodeBinding): string | null;
    protected _getAriaLabel(keybinding: ScanCodeBinding): string | null;
    protected _getElectronAccelerator(keybinding: ScanCodeBinding): string | null;
    protected _getUserSettingsLabel(keybinding: ScanCodeBinding): string | null;
    protected _isWYSIWYG(binding: ScanCodeBinding | null): boolean;
    protected _getDispatchPart(keybinding: ScanCodeBinding): string | null;
}
export declare class MacLinuxKeyboardMapper implements IKeyboardMapper {
    private readonly _isUSStandard;
    private readonly _OS;
    private readonly _codeInfo;
    private readonly _scanCodeKeyCodeMapper;
    private readonly _scanCodeToLabel;
    private readonly _scanCodeToDispatch;
    constructor(isUSStandard: boolean, rawMappings: IMacLinuxKeyboardMapping, OS: OperatingSystem);
    dumpDebugInfo(): string;
    private _leftPad;
    simpleKeybindingToScanCodeBinding(keybinding: SimpleKeybinding): ScanCodeBinding[];
    getUILabelForScanCodeBinding(binding: ScanCodeBinding | null): string | null;
    getAriaLabelForScanCodeBinding(binding: ScanCodeBinding | null): string | null;
    getDispatchStrForScanCodeBinding(keypress: ScanCodeBinding): string | null;
    getUserSettingsLabelForScanCodeBinding(binding: ScanCodeBinding | null): string | null;
    private _getElectronLabelForKeyCode;
    getElectronAcceleratorLabelForScanCodeBinding(binding: ScanCodeBinding | null): string | null;
    resolveKeybinding(keybinding: Keybinding): NativeResolvedKeybinding[];
    private _toResolvedKeybinding;
    private _generateResolvedKeybindings;
    resolveKeyboardEvent(keyboardEvent: IKeyboardEvent): NativeResolvedKeybinding;
    private _resolveSimpleUserBinding;
    resolveUserBinding(input: (SimpleKeybinding | ScanCodeBinding)[]): ResolvedKeybinding[];
    private static _charCodeToKb;
    static getCharCode(char: string): number;
}
